summaryrefslogtreecommitdiffstats
path: root/kdat/File.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdat/File.cpp')
-rw-r--r--kdat/File.cpp28
1 files changed, 14 insertions, 14 deletions
diff --git a/kdat/File.cpp b/kdat/File.cpp
index fd766b3..01a1e13 100644
--- a/kdat/File.cpp
+++ b/kdat/File.cpp
@@ -21,10 +21,10 @@
#include "File.h"
-File::File( File* parent, int size, int mtime, int startRecord, int endRecord, const TQString & name )
+File::File( File* tqparent, int size, int mtime, int startRecord, int endRecord, const TQString & name )
: _stubbed( FALSE ),
_name( name ),
- _parent( parent )
+ _parent( tqparent )
{
assert( endRecord >= startRecord );
@@ -34,9 +34,9 @@ File::File( File* parent, int size, int mtime, int startRecord, int endRecord, c
_union._data._endRecord = endRecord;
}
-File::File( File* parent, FILE* fptr, int offset )
+File::File( File* tqparent, FILE* fptr, int offset )
: _stubbed( TRUE ),
- _parent( parent )
+ _parent( tqparent )
{
_union._stub._fptr = fptr;
_union._stub._offset = offset;
@@ -44,9 +44,9 @@ File::File( File* parent, FILE* fptr, int offset )
File::~File()
{
- while ( _children.first() ) {
- delete _children.first();
- _children.removeFirst();
+ while ( _tqchildren.first() ) {
+ delete _tqchildren.first();
+ _tqchildren.removeFirst();
}
}
@@ -164,7 +164,7 @@ void File::write( FILE* fptr )
fwrite( &ival, sizeof( ival ), 1, fptr );
}
// Number of immediate children (4 bytes).
ival = getChildren().count();
fwrite( &ival, sizeof( ival ), 1, fptr );
@@ -175,10 +175,10 @@ void File::write( FILE* fptr )
}
//===== Write files =====
- ival = _children.count();
+ ival = _tqchildren.count();
fwrite( &ival, sizeof( ival ), 1, fptr );
- TQPtrListIterator<File> i( _children );
+ TQPtrListIterator<File> i( _tqchildren );
int count = 0;
for ( ; i.current(); ++i, count++ ) {
// Fill in the file offset.
@@ -236,8 +236,8 @@ TQString File::getName()
TQString File::getFullPathName()
{
TQString tmp = _name.copy();
- for ( File* parent = getParent(); parent; parent = parent->getParent() ) {
- tmp.prepend( parent->getName() );
+ for ( File* tqparent = getParent(); tqparent; tqparent = tqparent->getParent() ) {
+ tmp.prepend( tqparent->getName() );
}
return tmp;
@@ -252,7 +252,7 @@ const TQPtrList<File>& File::getChildren()
{
read();
- return _children;
+ return _tqchildren;
}
const TQPtrList<Range>& File::getRanges()
@@ -266,7 +266,7 @@ void File::addChild( File* file )
{
read();
- _children.append( file );
+ _tqchildren.append( file );
}
void File::calcRanges()
@@ -164,7 +164,7 @@ void File::write( FILE* fptr )
fwrite( &ival, sizeof( ival ), 1, fptr );
}
- // Number of immediate children (4 bytes).
+ // Number of immediate tqchildren (4 bytes).
ival = getChildren().count();
fwrite( &ival, sizeof( ival ), 1, fptr );